@@ -24,7 +24,7 @@
 
 
 // 20090728_001621 lcuk : set this to have a 25fps limit to framerate, otherwise runs at fastest possible
-#define LIMIT_FRAMERATE 1
+//#define LIMIT_FRAMERATE 1
 
 
 #include <stdio.h>
@@ -1562,7 +1562,7 @@ moar:
 				int hh=liqfont_textheight(infofont);
 				liqcliprect_drawtextinside_color(targetcr, infofont,  0,0, targetsurface->width,hh, buff,0, 255,128,128);
 			}
- */			
+ */		
  		
 			//liqapp_log("render refreshing");
 			
